@@ -112,7 +112,7 @@ TR_RJUSTIFY, /* default_flags 5 */
 0, /* timestart_from_savefile */
 0, /* timestart_from_savefile_valid */
 0, /* group_depth */
-
+0, /* hier_ignore_escapes */
 
 /*
  * baseconvert.c
@@ -883,7 +883,7 @@ NULL, /* signalarea_event_box */
 0, /* cached_mouseover_y */
 0, /* mouseover_counter */
 0, /* button2_debounce_flag */
-
+0, /* dragzoom_threshold */
 
 /*
  * simplereq.c
@@ -1796,6 +1796,7 @@ void reload_into_new_context_2(void)
  new_globals->enable_slider_zoom = GLOBALS->enable_slider_zoom;
  new_globals->context_tabposition = GLOBALS->context_tabposition;
  new_globals->use_standard_clicking = GLOBALS->use_standard_clicking;
+ new_globals->dragzoom_threshold = GLOBALS->dragzoom_threshold;
 
  new_globals->ignore_savefile_pane_pos = 1; /* to keep window from resizing/jumping */
  new_globals->ignore_savefile_pos = 1; /* to keep window from resizing/jumping */
@@ -1899,6 +1900,7 @@ void reload_into_new_context_2(void)
  new_globals->zoombase = GLOBALS->zoombase;
 
  new_globals->disable_ae2_alias = GLOBALS->disable_ae2_alias;
+ new_globals->hier_ignore_escapes = GLOBALS->hier_ignore_escapes;
 
  new_globals->splash_disable = 1; /* to disable splash for reload */
  new_globals->strace_repeat_count = GLOBALS->strace_repeat_count; /* for edgebuttons and also strace */
@@ -2791,6 +2793,8 @@ switch(type)
 							GLOBALS->ignore_savefile_pos = g_old->ignore_savefile_pos;
 							GLOBALS->ignore_savefile_size = g_old->ignore_savefile_size;
 
+							GLOBALS->hier_ignore_escapes = g_old->hier_ignore_escapes;
+
 							gtk_notebook_set_current_page(GTK_NOTEBOOK(GLOBALS->notebook), GLOBALS->this_context_page);
 							}
 
