@@ -113,6 +113,8 @@ int hier_max_level_shadow; /* from analyzer.c */
 TimeType timestart_from_savefile;
 char timestart_from_savefile_valid;
 int group_depth;
+char hier_ignore_escapes;
+
 
 /*
  * baseconvert.c
@@ -880,6 +882,7 @@ gint cached_mouseover_x; /* from signalwindow.c */
 gint cached_mouseover_y; /* from signalwindow.c */
 gint mouseover_counter; /* from signalwindow.c */
 unsigned button2_debounce_flag : 1;
+int dragzoom_threshold;
 
 
 /*
