@@ -20,6 +20,7 @@
 #ifdef __MINGW32__
 #include <windows.h>
 #endif
+#include "fsdb_wrapper_api.h"
 
 /*
 #define WAVE_CRASH_ON_GTK_WARNING
@@ -121,6 +122,7 @@ GLOBALS->keep_xz_colors = g_old->keep_xz_colors;
 GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
 GLOBALS->zoom_dyn = g_old->zoom_dyn;
 GLOBALS->zoom_dyne = g_old->zoom_dyne;
+GLOBALS->hier_ignore_escapes = g_old->hier_ignore_escapes;
 
 reformat_time(timestr, GLOBALS->tims.first + GLOBALS->global_time_offset, GLOBALS->time_dimension);
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),timestr);
@@ -215,6 +217,22 @@ for(i=0;i<GLOBALS->num_notebook_pages;i++)
 #endif
 
 
+#ifdef WAVE_FSDB_READER_IS_PRESENT
+static void close_all_fsdb_files(void) /* otherwise fsdb can leave around stray files if .gz/.bz2 was in use */
+{
+unsigned int i;
+for(i=0;i<GLOBALS->num_notebook_pages;i++)
+	{
+	if((*GLOBALS->contexts)[i]->extload_ffr_ctx)
+		{
+		fsdbReaderClose((*GLOBALS->contexts)[i]->extload_ffr_ctx);
+		(*GLOBALS->contexts)[i]->extload_ffr_ctx = NULL;
+		}
+        }
+}
+#endif
+
+
 static void print_help(char *nam)
 {
 #if defined(EXTLOAD_SUFFIX) && defined(EXTCONV_PATH)
@@ -323,6 +341,7 @@ XID_GETOPT
 RPC_GETOPT
 CHDIR_GETOPT
 RPC_GETOPT3
+"  -4, --rcvar                specify single rc variable values individually\n"
 INTR_GETOPT
 "  -C, --comphier             use compressed hierarchy names (slower)\n"
 "  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
@@ -469,11 +488,13 @@ int tcl_interpreter_needs_making = 0;
 struct Global *old_g = NULL;
 
 int splash_disable_rc_override = 0;
-int mainwindow_already_built;
+int mainwindow_already_built = 0;
 #ifdef MAC_INTEGRATION
 GdkPixbuf *dock_pb;
 #endif
 
+struct rc_override *rc_override_head = NULL, *rc_override_curr = NULL;
+
 WAVE_LOCALE_FIX
 
 /* Initialize the GLOBALS structure for the first time... */
@@ -641,6 +662,7 @@ if(!GLOBALS)
 	GLOBALS->zoombase = old_g->zoombase;
 	GLOBALS->splash_disable = old_g->splash_disable;
 	GLOBALS->use_pango_fonts = old_g->use_pango_fonts;
+	GLOBALS->hier_ignore_escapes = old_g->hier_ignore_escapes;
 
 	GLOBALS->ruler_origin = old_g->ruler_origin;
 	GLOBALS->ruler_step = old_g->ruler_step;
@@ -650,6 +672,7 @@ if(!GLOBALS)
 	GLOBALS->vlist_prepack = old_g->vlist_prepack;
 	GLOBALS->do_dynamic_treefilter = old_g->do_dynamic_treefilter;
 	GLOBALS->use_standard_clicking = old_g->use_standard_clicking;
+	GLOBALS->dragzoom_threshold = old_g->dragzoom_threshold;
 	GLOBALS->use_toolbutton_interface = old_g->use_toolbutton_interface;
 
 	GLOBALS->use_scrollwheel_as_y = old_g->use_scrollwheel_as_y;
@@ -723,12 +746,16 @@ if(!gtkwave_argv0_cached) gtkwave_argv0_cached = argv[0]; /* for new window opti
 init_filetrans_data(); /* for file translation splay trees */
 init_proctrans_data(); /* for proc translation structs */
 init_ttrans_data();    /* for transaction proc translation structs */
+
 if(!mainwindow_already_built)
 	{
 	atexit(remove_all_proc_filters);
 	atexit(remove_all_ttrans_filters);
 #if defined __MINGW32__
 	atexit(close_all_fst_files);
+#endif
+#ifdef WAVE_FSDB_READER_IS_PRESENT
+	atexit(close_all_fsdb_files);
 #endif
 	}
 
@@ -778,10 +805,11 @@ while (1)
 		{"rpcid", 1, 0, '1' },
 		{"chdir", 1, 0, '2'},
 		{"restore", 0, 0, '3'},
+                {"rcvar", 1, 0, '4'},
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:2:3", long_options,
+        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:2:34:", long_options,
 &option_index);
 
         if (c == -1) break;     /* no more args */
@@ -978,6 +1006,23 @@ while (1)
 			strcpy(override_rc, optarg);
 			break;
 
+		case '4':
+			{
+ 			struct rc_override *rco = calloc_2(1, sizeof(struct rc_override));
+			rco->str = strdup_2(optarg);
+
+			if(rc_override_curr)
+				{
+				rc_override_curr->next = rco;
+				rc_override_curr = rco;
+				}
+				else
+				{
+				rc_override_head = rc_override_curr = rco;
+				}
+			}
+			break;
+
                 case 's':
 			if(GLOBALS->skip_start) free_2(GLOBALS->skip_start);
 			GLOBALS->skip_start = malloc_2(strlen(optarg)+1);
@@ -1267,6 +1312,24 @@ if(output_name)
 	}
 
 fprintf(stderr, "\n%s\n\n",WAVE_VERSION_INFO);
+
+
+if(!old_g) /* copy all variables earlier when old_g is set */
+	{
+	while(rc_override_head)
+		{
+		int rco_succ;
+		char *rco_copy_str = strdup_2(rc_override_head->str);
+		rco_succ = insert_rc_variable(rc_override_head->str);
+		fprintf(stderr, "RCVAR   | '%s' %s\n", rco_copy_str, rco_succ ? "FOUND" : "NOT FOUND");
+		free_2(rco_copy_str);
+		rc_override_curr = rc_override_head->next;
+		free_2(rc_override_head->str);
+		free_2(rc_override_head);
+		rc_override_head = rc_override_curr;
+		}
+	}
+
 if(!is_wish)
 	{
 	if(tcl_interpreter_needs_making)
@@ -1331,7 +1394,11 @@ if(is_missing_file)
 	}
 else
 #if defined(EXTLOAD_SUFFIX)
-if(suffix_check(GLOBALS->loaded_file_name, "."EXTLOAD_SUFFIX) && !opt_vcd)
+if(
+   (suffix_check(GLOBALS->loaded_file_name, "."EXTLOAD_SUFFIX      ) && !opt_vcd) ||
+   (suffix_check(GLOBALS->loaded_file_name, "."EXTLOAD_SUFFIX".gz" ) && !opt_vcd) ||   /* loader automatically does gzip -cd */
+   (suffix_check(GLOBALS->loaded_file_name, "."EXTLOAD_SUFFIX".bz2") && !opt_vcd)      /* loader automatically does bzip2 -cd */
+  )
 	{
 	TimeType extload_max;
 
@@ -2310,6 +2377,18 @@ if(!mainwindow_already_built)
 	gtk_table_attach (GTK_TABLE (whole_table), GLOBALS->force_toolbars?toolhandle:top_table, 0, 16, 0, 1,
 	                      	GTK_FILL | GTK_EXPAND,
 	                      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
+
+	if(!GLOBALS->do_resize_signals)
+		{
+		int dri;
+        	for(dri=0;dri<2;dri++)
+        	        {
+        	        GLOBALS->signalwindow_width_dirty=1;
+        	        MaxSignalLength();
+        	        signalarea_configure_event(GLOBALS->signalarea, NULL);
+        	        wavearea_configure_event(GLOBALS->wavearea, NULL);
+        	        }
+		}
 	}
 
 
@@ -2419,7 +2498,11 @@ if(1)	/* here in order to calculate window manager delta if present... window is
 
 init_busy();
 
-if(scriptfile)
+if(scriptfile
+#if defined(HAVE_LIBTCL)
+        && GLOBALS->interp
+#endif
+)
 	{
 	execute_script(scriptfile, 1); /* deallocate the name in the script because context might swap out from under us! */
 	scriptfile=NULL;
